<?php namespace EscapeWork\Manager\Commands;

use EscapeWork\Manager\Models\User;
use EscapeWork\Manager\Seeds\ManagerTableSeeder;
use EscapeWork\Manager\Repositories\User\UserRepository;
use Illuminate\Console\Command;
use Symfony\Component\Console\Input\InputOption;
use Symfony\Component\Console\Input\InputArgument;
use Config;

class ConfigureCommand extends Command
{

    /**
     * The console command name.
     *
     * @var string
     */
    protected $name = 'manager:configure';

    /**
     * The console command description.
     *
     * @var string
     */
    protected $description = 'Migrations, Seeds, plugins e tudo que precisar ser configurado.';

    /**
     * Create a new command instance.
     *
     * @return void
     */
    public function __construct(UserRepository $user)
    {
        parent::__construct();

        $this->user = $user;
    }

    /**
     * Execute the console command.
     *
     * @return void
     */
    public function fire()
    {
        $this->comment('--- Configurando escapework/manager ---');

        # migrations
        $this->comment('Realizando as migrações do escapework/manager...');
        $this->call('migrate', array('--package' => 'escapework/manager'));

        # seed
        $this->comment('Fazendo os seeds...');
        $seeder = new ManagerTableSeeder();
        $seeder->setContainer($this->laravel)->setCommand($this)->run();
        $this->info('escapework/manager seeded!');

        # asset:publish
        $this->comment('Publicando assets do escapework/manager...');
        try {
            $this->call('asset:publish', array('package' => 'escapework/manager'));
        } catch (\RuntimeException $e) {

        }

        if (User::count() == 0) {
            $fields['name']     = $this->ask('Qual o nome do usuário administrador?');
            $fields['email']    = $this->ask('Qual o e-mail do usuário administrador? (será utilizado para login)');
            $fields['password'] = $this->secret('Qual a senha do usuário administrador?');

            $this->user->role_id = 1; # administrador
            $this->user->fill($fields);
            $this->user->save();

            $this->info('Usuário ' . $this->user->name . ' criado com sucesso!');
        }

        $this->comment('--- escapework/manager configurado ---');

        # configurando os outros pacotes
        $packages = Config::get('manager::packages');

        foreach ($packages as $package) {
            $this->call($package.':configure');
        }
    }

    /**
     * Get the console command arguments.
     *
     * @return array
     */
    protected function getArguments()
    {
        return array();
    }

    /**
     * Get the console command options.
     *
     * @return array
     */
    protected function getOptions()
    {
        return array();
    }

}
