<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Facades\Check;
use EscapeWork\Manager\Facades\UserPassword;
use EscapeWork\Manager\Facades\UserAuth;
use Illuminate\Routing\Controller;
use App;
use View;
use Input;
use Msg;
use Redirect;
use Session;

class ManagerController extends Controller
{

    /**
     * The page for check the permissions
     *
     * @var  string
     */
    protected $permissionPage;

    public function __construct()
    {
        $this->user         = App::make('EscapeWork\Manager\Repositories\User\UserRepository');
        $this->userReminder = App::make('EscapeWork\Manager\Repositories\UserReminder\UserReminderRepository');
    }

    public function enableDefaultFilters($permissionPage)
    {
        $this->permissionPage = $permissionPage;

        $this->enableCreateFilter()
             ->enableShowFilter()
             ->enableUpdateFilter()
             ->enableDestroyFilter();
    }

    public function enableCreateFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'create');
        }, array('only' => array('create', 'store')));

        return $this;
    }

    public function enableUpdateFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'update');
        }, array('only' => array('edit', 'update')));

        return $this;
    }

    public function enableDestroyFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'destroy');
        }, array('only' => array('destroy')));

        return $this;
    }

    public function enableShowFilter()
    {
        $permissionPage = $this->permissionPage;

        $this->beforeFilter(function() use($permissionPage)
        {
            Check::canOrFail($permissionPage, 'read');
        }, array('only' => array('show')));

        return $this;
    }
}
