<?php namespace EscapeWork\Manager\Controllers;

use EscapeWork\Manager\Repositories\Role\RoleRepository;
use EscapeWork\Manager\Repositories\Page\PageRepository;
use EscapeWork\Manager\Repositories\RoleAction\RoleActionRepository;
use App;
use Input;
use Redirect;
use Msg;
use View;
use Config;

class RoleController extends ManagerController
{

    public function __construct(RoleRepository $role, PageRepository $page, RoleActionRepository $roleAction)
    {
        parent::__construct();

        $this->role       = $role;
        $this->page       = $page;
        $this->roleAction = $roleAction;

        $this->enableDefaultFilters('roles');
    }

    /**
     * Listing the roles
     */
    public function index()
    {
        $view        = View::make(Config::get('manager::views.roles.index'));
        $view->roles = $this->role->all();

        return $view;
    }

    /**
     * Form for creating a role
     */
    public function create()
    {
        Msg::setInfo('Inserindo uma nova regra');

        $view              = View::make(Config::get('manager::views.roles.form'));
        $view->role        = $this->role;
        $view->edit        = false;
        $view->pages       = $this->page->all();
        $view->roleActions = $this->roleAction->getByRole($this->role->id);

        return $view;
    }

    /**
     * Storing a new role
     */
    public function store()
    {
        $this->role->fill(Input::all());

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.create')
                    ->withInput()
                    ->with('errors', $this->role->getValidationErrors());
        }

        $this->role->save();

        # saving the actions allowed
        $this->roleAction->role_id = $this->role->id;
        $this->roleAction->saveAll(Input::get('action'), Input::get('page'));

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi inserida com sucesso!');
    }

    /**
     * Form for editing a role
     */
    public function edit($id)
    {
        $this->role = $this->role->findOrFail($id);

        Msg::setInfo('Editando o perfil <strong>'.$this->role->title.'</strong>');

        $view              = View::make(Config::get('manager::views.roles.form'));
        $view->role        = $this->role;
        $view->edit        = true;
        $view->pages       = $this->page->all();
        $view->roleActions = $this->roleAction->getByRole($this->role->id);

        return $view;
    }

    /**
     * Updating the role
     */
    public function update($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->fill(Input::all());

        if (! $this->role->validate()) {
            return Redirect::route('manager.roles.edit', $this->role->id)
                    ->withInput()
                    ->withErrors($this->role->getValidationErrors());
        }

        $this->role->save();

        # saving the actions allowed
        $this->roleAction->role_id = $this->role->id;
        $this->roleAction->deleteByRole($this->role->id);
        $this->roleAction->saveAll(Input::get('action'), Input::get('page'));

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi atualizada com sucesso!');
    }

    /**
     * Destroying the role
     */
    public function destroy($id)
    {
        $this->role = $this->role->findOrFail($id);
        $this->role->delete();

        return Redirect::route('manager.roles.index')
                ->with('message', 'A regra <strong>'.$this->role->title.'</strong> foi excluída com sucesso!');
    }
}
