<?php namespace EscapeWork\Manager\Models;

use EscapeWork\Manager\Repositories\UserRepository;
use EscapeWork\LaravelHelpers\Eloquent;

class RoleAction extends Eloquent
{

    /**
     * Table
     */
    protected $table = 'manager_role_actions';

    /**
     * Fillable fields
     */
    public $fillable = array(
        'role_id',
        'action_id',
        'page_id'
    );

    /**
     * The primary key for the model.
     * Not really the primary key, but is used in Illuminate\Database\Eloquent\Collection->contains() method
     *
     * @var string
     */
    protected $primaryKey = 'action_id';

    /**
     * Belongs to Page
     */
    public function page()
    {
        return $this->belongsTo('EscapeWork\Manager\Models\Page');
    }

    /**
     * Belongs to Role
     */
    public function role()
    {
        return $this->belongsTo('EscapeWork\Manager\Models\Role');
    }

    /**
     * Belongs to PageAction
     */
    public function action()
    {
        return $this->belongsTo('EscapeWork\Manager\Models\PageAction', 'action_id');
    }

    /**
     * Scope for join with the users table
     */
    public function scopeJoinUser($query)
    {
        return $query->join('manager_users', 'manager_users.role_id', '=', 'manager_role_actions.role_id');
    }

    /**
     * Scope for join with the pages table
     */
    public function scopeJoinPage($query)
    {
        return $query->join('manager_pages', 'manager_pages.id', '=', 'manager_role_actions.page_id');
    }

    /**
     * Scope for join with the actions table
     */
    public function scopeJoinAction($query)
    {
        return $query->join('manager_page_actions', 'manager_page_actions.id', '=', 'manager_role_actions.action_id');
    }
}
