<?php namespace EscapeWork\Manager\Models;

use EscapeWork\LaravelHelpers\Eloquent;
use Illuminate\Auth\UserInterface;
use Illuminate\Auth\Reminders\RemindableInterface;
use Hash;

class User extends Eloquent implements UserInterface, RemindableInterface
{

    /**
     * Table
     */
    protected $table = 'manager_users';

    /**
     * The attributes excluded from the model's JSON form.
     *
     * @var array
     */
    protected $hidden = array('password');

    /**
     * Fillable fields
     */
    public $fillable = array(
        'id',
        'role_id',
        'email',
        'password',
        'name',
    );

    /**
     * Regras para validação
     */
    public static $validationRules = array(
        'role_id' => array('required', 'integer'),
        'name'    => array('required'),
        'email'   => array('required', 'email', 'unique' => 'unique:manager_users,email,:id:'),
    );

    /**
     * Mensagens para validação
     */
    public static $validationMessages = array(
        'role_id.required' => 'Selecione um perfil para o usuário',
        'name.required'    => 'O nome do usuário é obrigatório',
        'email.required'   => 'O e-mail do usuário é obrigatório',
        'email.email'      => 'O e-mail do usuário é precisa ser válido',
        'email.unique'     => 'O e-mail digitado já está cadastrado em outro usuário. Selecione outro.',
    );

    /**
     * Get the unique identifier for the user.
     *
     * @return mixed
     */
    public function getAuthIdentifier()
    {
        return $this->getKey();
    }

    /**
     * Get the password for the user.
     *
     * @return string
     */
    public function getAuthPassword()
    {
        return $this->password;
    }

    /**
     * Get the token value for the "remember me" session.
     *
     * @return string
     */
    public function getRememberToken()
    {
        return $this->remember_token;
    }

    /**
     * Set the token value for the "remember me" session.
     *
     * @param  string  $value
     * @return void
     */
    public function setRememberToken($value)
    {
        $this->remember_token = $value;
    }

    /**
     * Get the column name for the "remember me" token.
     *
     * @return string
     */
    public function getRememberTokenName()
    {
        return 'remember_token';
    }

    /**
     * Get the e-mail address where password reminders are sent.
     *
     * @return string
     */
    public function getReminderEmail()
    {
        return $this->email;
    }

    /**
     * Mutator for hashing the password when setting
     *
     * @return void
     */
    public function setPasswordAttribute($password)
    {
        if ($password != '') {
            $this->attributes['password'] = Hash::make($password);
        }
    }

    /**
     * User belongs to a Role
     */
    public function role()
    {
        return $this->belongsTo('EscapeWork\Manager\Models\Role', 'role_id');
    }
}
