<?php namespace EscapeWork\Manager;

use EscapeWork\Manager\Repositories\User\UserRepository;
use EscapeWork\Manager\Repositories\RoleAction\RoleActionRepository;
use EscapeWork\Manager\Exceptions\UnauthorizedExcpetion;

class Permission
{

    /**
     * Array of allowed actions
     *
     * @var  array
     */
    public $actions;

    /**
     * Initializing the Permission Class
     *
     * @param UserRepository       $user
     * @param RoleActionRepository $roleAction
     */
    public function __construct($user, RoleActionRepository $roleAction)
    {
        $this->user       = $user;
        $this->roleAction = $roleAction;
    }

    /**
     * Fetching the allowed for the actual user
     *
     * @access  public
     * @return  void
     */
    public function fetchAllowedActions()
    {
        if (! $this->user) {
            return $this;
        }

        $this->actions = $this->roleAction->getUserActions($this->user)->toArray();

        return $this;
    }

    /**
     * Formating the allowed actions array in the format Page => array(actions)
     */
    public function formatAllowedActionsArray()
    {
        $actions = $this->actions;
        $this->actions = array();

        foreach ((array) $actions as $action) {
            if (! isset($this->actions[$action['pageSlug']])) {
                $this->actions[$action['pageSlug']] = array();
            }

            $this->actions[$action['pageSlug']][$action['actionType']] = $action;
        }

        return $this;
    }

    /**
     * Checking if the user has permission to access determined page
     * If not, throw an EscapeWork\Manager\UnauthorizedExcpetion
     *
     * @param  string $page
     * @param  string $action
     */
    public function canOrFail($page, $action)
    {
        if (! $roleAction = $this->can($page, $action)) {
            throw new UnauthorizedExcpetion('Você não tem permissão para acessar esta página');
        }

        return $roleAction;
    }

    /**
     * Checking if the user has permission to access determined page
     *
     * @param   string $page
     * @param   string $action
     * @return  boolean
     */
    public function can($page, $action)
    {
        if ($this->user && $this->user->role->all_permissions) {
            return true;
        }

        return isset($this->actions[$page][$action]);
    }

    /**
     * Checking if the user can access unless one action on some page
     * Normaly used for menus
     *
     * @access  public
     * @param   string $page
     * @return  boolean
     */
    public function canAny($page)
    {
        if ($this->user && $this->user->role->all_permissions) {
            return true;
        }

        return isset($this->actions[$page]);
    }

    /**
     * Checking if the user is a admin
     */
    public function isAdmin()
    {
        return $this->user && $this->user->role->all_permissions;
    }
}
