<?php namespace EscapeWork\Manager\Providers;

use EscapeWork\Manager\Extensions\User\Guard;
use EscapeWork\Manager\Facades\UserAuth;
use Illuminate\Support\ServiceProvider;
use Illuminate\Auth\EloquentUserProvider;
use Illuminate\Auth\Reminders\PasswordBroker;
use Illuminate\Auth\Reminders\DatabaseReminderRepository;

class UserServiceProvider extends ServiceProvider
{

    public function boot()
    {
        $this->registerReminders();
    }

    /**
     * Register the service provider.
     *
     * @return void
     */
    public function register()
    {
        $this->registerAuth();
    }

    /**
     * Simulando uma nova instancia de Auth
     */
    protected function registerAuth()
    {
        $this->registerProvider();
        $this->registerGuard();
    }

    protected function registerProvider()
    {
        $this->app['escapework.manager.user.auth.provider'] = $this->app->share(function($app)
        {
            return new EloquentUserProvider(
                $app['hash'],
                'EscapeWork\Manager\Models\User'
            );
        });
    }

    protected function registerGuard()
    {
        $this->app['escapework.manager.user.auth'] = $this->app->share(function($app)
        {
            $guard = new Guard(
                $app['escapework.manager.user.auth.provider'],
                $app['session.store']
            );

            $guard->setCookieJar($app['cookie']);
            $guard->setDispatcher($app['events']);
            return $guard->setRequest($app->refresh('request', $guard, 'setRequest'));
        });
    }

    /**
     * Simulando uma nova instancia de Password::
     */
    protected function registerReminders()
    {
        # DatabaseReminderRepository
        $this->registerReminderDatabaseRepository();

        # PasswordBroker
        $this->app['escapework.manager.user.reminder'] = $this->app->share(function($app)
        {
            return new PasswordBroker(
                $app['escapework.manager.user.reminder.repository'],
                $app['escapework.manager.user.auth.provider'],
                $app['mailer'],
                'manager::emails.user.reminder'
            );
        });
    }

    protected function registerReminderDatabaseRepository()
    {
        $this->app['escapework.manager.user.reminder.repository'] = $this->app->share(function($app)
        {
            $connection   = $app['db']->connection();
            $table        = 'manager_user_reminders';
            $key          = $app['config']['app.key'];

            return new DatabaseReminderRepository($connection, $table, $key);
        });
    }

    /**
     * Get the services provided by the provider.
     *
     * @return array
     */
    public function provides()
    {
        return array(
            'escapework.manager.user.auth',
            'escapework.manager.user.auth.provider',
            'escapework.manager.user.reminder.repository',
            'escapework.manager.user.reminder',
        );
    }
}
