<?php namespace EscapeWork\Manager\Repositories;

use Illuminate\Database\Eloquent\Model;

abstract class BaseEloquentRepository
{

    /**
     * The model instance
     *
     * @var  Illuminate\Database\Eloquent\Model
     */
    protected $model;

    /**
     * Valid orderBy fields
     */
    protected $orderByFields = array();

    /**
     * Set hte model instance
     */
    public function setModel(Model $model)
    {
        $this->model = $model;
        return $this;
    }

    /**
     * Get hte model instance
     */
    public function getModel()
    {
        return $this->model;
    }

    public function __get($key)
    {
        return $this->model->getAttribute($key);
    }

    public function __set($key, $value)
    {
        $this->model->setAttribute($key, $value);
    }

    public function fill(array $data = array())
    {
        $this->model->fill($data);
    }

    public function all()
    {
        return $this->model->all();
    }

    public function get()
    {
        return $this->model->get();
    }

    public function validate(array $rules = array())
    {
        return $this->model->validate($rules);
    }

    public function find($id)
    {
        if ($model = $this->model->find($id)) {
            $this->model = $model;
            return $this;
        }

        return null;
    }

    public function findOrFail($id)
    {
        $this->model = $this->model->findOrFail($id);
        return $this;
    }

    public function findOrFailBy($field, $value)
    {
        $this->model = $this->model->findOrFailBy($field, $value);
        return $this;
    }

    public function delete()
    {
        return $this->model->delete();
    }

    public function forceDelete()
    {
        return $this->model->forceDelete();
    }

    public function save()
    {
        return $this->model->save();
    }

    public function HTMLOptions($id = null, $field = 'title', $all = null)
    {
        return $this->model->HTMLOptions($id, $field, $all);
    }

    public function paginate($take = 20)
    {
        return $this->model->paginate($take);
    }

    /**
     * @return Illuminate\Support\MessageBag
     */
    public function getValidationErrors()
    {
        return $this->model->messageBag;
    }

    /**
     * Configurando o orderBy do elemento
     */
    protected function configureOrderBy(&$query, $params = array(), $defaultField = null, $defaultDirection = 'asc')
    {
        if (! isset($params['orderBy'])) {
            if ($defaultField) {
                $query->orderBy($defaultField, $defaultDirection);
            }

            return;
        }

        $type              = strpos($params['orderBy'], '+desc') ? 'desc' : 'asc';
        $params['orderBy'] = str_replace('+desc', '', $params['orderBy']);

        if (in_array($params['orderBy'], $this->orderByFields)) {
            $query->orderBy($params['orderBy'], $type);
        }
    }

    public function toJson()
    {
        return $this->model->toJson();
    }

    public function toArray()
    {
        return $this->model->toArray();
    }

    public function __toString()
    {
        return $this->model->toJson();
    }

    public function __call($method, $args)
    {
        return call_user_func_array(array($this->model, $method), $args);
    }
}
