<?php namespace EscapeWork\Manager\Repositories\PageAction;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\Models\PageAction;

class EloquentPageActionRepository extends BaseEloquentRepository implements PageActionRepository
{

    public function __construct(PageAction $pageAction)
    {
        $this->model = $pageAction;
    }

    public function getDefaultActions()
    {
        return $this->model->getDefaultActions();
    }

    /**
     * Saving all page actions
     *
     * @param  array $actions
     */
    public function saveAll($titles = array(), $types = array())
    {
        foreach ((array) $titles as $i => $title) {
            $type = $types[$i];

            $this->insertNew($this->page_id, $title, $type);
        }
    }

     /**
     * Inserting a new action in the page
     */
    public function insertNew($page_id, $title, $type)
    {
        $pageAction = $this->model->newFromBuilder();
        $pageAction->fill(array(
            'page_id' => $page_id,
            'title'   => $title,
            'type'    => $type,
        ));

        return $pageAction->save();
    }

    /**
     * Deleting all actions
     */
    public function deleteByPage($page_id)
    {
        return $this->model->where('page_id', '=', $page_id)->delete();
    }

    /**
     * Returning the actions of a determined page
     */
    public function getByPage($page_id)
    {
        return $this->model->where('page_id', '=', $page_id)->get();
    }

    /**
     * Checking if the actions has changed
     *
     * @param   Illuminate\Database\Eloquent\Collection $pageActions
     * @param   array                                   $types
     * @return  booleam
     */
    public function hasChanged($pageActions, $types)
    {
        $newCount = count($types);
        $oldCount = 0;

        if (count($pageActions) != $newCount) {
            return true;
        }

        foreach ($pageActions as $pageAction) {
            if (in_array($pageAction->type, $types)) {
                $oldCount++;
            }
        }

        return $newCount != $oldCount;
    }
}
