<?php namespace EscapeWork\Manager\Repositories\RoleAction;

use EscapeWork\Manager\Repositories\BaseEloquentRepository;
use EscapeWork\Manager\Models\RoleAction;

class EloquentRoleActionRepository extends BaseEloquentRepository implements RoleActionRepository
{

    public function __construct(RoleAction $roleAction)
    {
        $this->model = $roleAction;
    }

    /**
     * Saving all actions from a role
     */
    public function saveAll($actions, $pages)
    {
        foreach ($actions as $action_id) {
            $page_id = $pages[$action_id];

            $this->insertNew($this->role_id, $action_id, $page_id);
        }
    }

    /**
     * Criando uma nova ação
     */
    public function insertNew($role_id, $action_id, $page_id)
    {
        $this->model->create(array(
            'role_id'   => $role_id,
            'action_id' => $action_id,
            'page_id'   => $page_id,
        ));
    }

    /**
     * Destroying all actions in a role
     */
    public function deleteByRole($role_id)
    {
        $this->model->where('role_id', '=', $role_id)->delete();
    }

    /**
     * Destroying all role actions in a specific page
     */
    public function deleteByPage($page_id)
    {
        $this->model->where('page_id', '=', $page_id)->delete();
    }

    /**
     * Getting all actions in a role
     */
    public function getByRole($role_id)
    {
        return $this->model->where('role_id', '=', $role_id)->get();
    }

    /**
     * Checking if some user has permission to do some action in some page
     *
     * @param  UserRepository $user
     * @param  string         $page
     * @param  string         $action
     */
    public function hasPermission($user, $page, $action)
    {
        return $this->model
                    ->select('manager_users.id')
                    ->joinUser()
                    ->joinPage()
                    ->joinAction()
                    ->where('manager_users.id', '=', $user->id)
                    ->where('manager_pages.slug', '=', $page)
                    ->where('manager_page_actions.type', '=', $action)
                    ->first();
    }

    /**
     * Fetching all the user actions
     *
     * @access  public
     * @param   UserRepository $user
     */
    public function getUserActions($user)
    {
        return $this->model
                    ->select('manager_pages.title as pageTitle',
                             'manager_pages.slug as pageSlug',
                             'manager_page_actions.title as actionTitle',
                             'manager_page_actions.type as actionType'
                    )
                    ->joinUser()
                    ->joinPage()
                    ->joinAction()
                    ->where('manager_users.id', '=', $user->id)
                    ->get();
    }
}
