<?php namespace EscapeWork\Manager\Services\Exporter;

use Response;

class CSVExporter implements ExporterInterface
{

    /**
     * Line of the file
     */
    protected $lines = array();

    /**
     * Writing a line
     */
    public function writeLine(array $data)
    {
        $this->lines[] = $data;
    }

    /**
     * Exporting
     *
     * @param   $filename string
     * @return  Illuminate\Http\Response
     */
    public function export(array $options = array())
    {
        $output = '';
        foreach ($this->lines as $line) {
            $output .= implode("\t", $line) . "\n";
        }

        $content = $this->buildOutput($output);
        return $this->buildResponse($content, $options['filename']);
    }

    /**
     * Writing the output
     */
    protected function buildOutput($output)
    {
        $content  = chr(255) . chr(254);
        $content .= iconv('UTF-8', 'UTF-16LE', $output);

        return $content;
    }

    /**
     * Building the response
     */
    public function buildResponse($content, $filename)
    {
        $response = Response::make($content);
        $response->header('Content-Description', 'File Transfer');
        $response->header('Content-Type', 'application/vnd.ms-excel');
        $response->header('Content-Disposition', 'attachment; filename='.$filename.'.csv');
        $response->header('Content-Transfer-Encoding', 'binary');
        $response->header('Expires', '0');
        $response->header('Cache-Control', 'must-revalidate, post-check=0, pre-check=0');
        $response->header('Pragma', 'public');

        return $response;
    }
}
