<?php namespace EscapeWork\Manager;

use EscapeWork\Manager\Models\User;
use EscapeWork\Manager\Models\Role;
use App;
use Mockery as m;

class TestCase extends \TestCase
{

    public function setUp()
    {
        parent::setUp();

        $this->createPaginatorHelper();

        # autenticando o usuário
        $this->mockAuthUser();
        $this->mockPermissionsFetch();
    }

    /**
     * Mocking the auth user
     */
    protected function mockAuthUser()
    {
        $user                        = new User(['name' => 'Escape Manager']);
        $user->role                  = new Role;
        $user->role->all_permissions = true;

        $this->be($user);
    }

    /**
     * Mocking the permissions fetch
     */
    public function mockPermissionsFetch()
    {
        $permission = m::mock('EscapeWork\Manager\Permission');
        $permission->shouldReceive('fetchAllowedActions')->andReturn($permission);
        $permission->shouldReceive('formatAllowedActionsArray')->andReturn($permission);
        $permission->shouldReceive('canOrFail')->andReturn(true);
        $permission->shouldReceive('can')->andReturn(true);
        $permission->shouldReceive('canAny')->andReturn(true);
        App::instance('EscapeWork\Manager\Permission', $permission);
    }

    /**
     * Creating a paginator helpers to Unit Testing
     */
    public function createPaginatorHelper()
    {
        $this->paginate = m::mock('PaginatorMock');
        $this->paginate->shouldReceive('links');
        $this->paginate->shouldReceive('getCurrentPage');
        $this->paginate->shouldReceive('getLastPage');
        $this->paginate->shouldReceive('getPerPage');
        $this->paginate->shouldReceive('getTotal');
        $this->paginate->shouldReceive('getFrom');
        $this->paginate->shouldReceive('getTo');
        $this->paginate->shouldReceive('appends')->andReturn($this->paginate);
    }
}