<!doctype html>
<html lang="pt-BR">
<head>
    <meta charset="UTF-8" />
    <title>{{ Config::get('manager::title') }} | {{ Config::get('manager::subtitle') }}</title>

    <!-- CSS -->
    @section('styles')
        <link rel="shortcut icon" href="{{ asset(Config::get('manager::favicon_path')) }}" />
        <meta name="viewport" content="width=device-width, initial-scale=1.0" />
        <link rel="stylesheet" href="{{ asset('packages/escapework/manager/assets/css/vendor/bootstrap/bootstrap.min.css') }}" />
        <link rel="stylesheet" href="{{ asset('packages/escapework/manager/assets/css/vendor/bootstrap/bootstrap-responsive.min.css') }}" />
        <link rel="stylesheet" href="{{ asset('packages/escapework/manager/assets/css/vendor/jquery-ui/flick/jquery-ui.min.css') }}" />
        <link rel="stylesheet" href="{{ asset('packages/escapework/manager/assets/css/main.css') }}" />
    @show
</head>
<body>
    <div class="navbar navbar-inverse">
        <div class="navbar-inner">
            <a class="brand" href="{{ Config::get('manager::url') }}">{{ Config::get('manager::title') }}</a>

            <ul class="nav">
                @if (! is_null(Config::get('manager::views.menu')) && ! EscapeWork\Manager\Facades\UserAuth::guest())
                    @include(Config::get('manager::views.menu'))
                @endif
            </ul>

            @if (! EscapeWork\Manager\Facades\UserAuth::guest())
                <ul class="nav pull-right">
                    <li class="dropdown">
                        <a href="#" class="dropdown-toggle" data-toggle="dropdown">
                            {{ EscapeWork\Manager\Facades\UserAuth::user()->name }} &nbsp;
                            <b class="caret"></b>
                        </a>

                        <ul class="dropdown-menu">
                            @if (Check::canAny('usuarios'))
                                <li>
                                    <a tabindex="-1" href="{{ route('manager.users.index') }}">
                                        <i class="icon-user"></i>
                                        Usuários
                                    </a>
                                </li>
                            @endif

                            @if (Check::canAny('roles'))
                                <li>
                                    <a tabindex="-1" href="{{ route('manager.roles.index') }}">
                                        <i class="icon-book"></i>
                                        Perfis
                                    </a>
                                </li>
                            @endif

                            @if (Check::canAny('pages'))
                                <li>
                                    <a tabindex="-1" href="{{ route('manager.pages.index') }}">
                                        <i class="icon-file"></i>
                                        Páginas
                                    </a>
                                </li>

                                <li class="divider"></li>
                            @endif

                            @if (Check::isAdmin())
                                <li>
                                    <a href="{{ route('manager.logs.index') }}">
                                        <i class="icon-file"></i>
                                        Logs
                                    </a>
                                </li>

                                <li class="divider"></li>
                            @endif

                            <li>
                                <a href="{{ route('manager.logout') }}">
                                    <i class="icon-off"></i>
                                    Sair
                                </a>
                            </li>
                        </ul><!-- .dropdown-menu -->
                    </li><!-- .dropdown -->
                </ul>
            @endif
        </div>
    </div><!-- .navbar -->

    <div class="container">
        <section class="content">
            @yield('content')
        </section><!-- .content -->
    </div><!-- .container -->


    <!-- ========================================================================
         Componentes utilizados via JS
         ======================================================================== -->
    <div id="modal-delete" class="modal hide fade">
        <div class="modal-header">
            <a href="#" class="close" data-dismiss="modal">&times;</a>
            <h3>Confirmação</h3>
        </div>

        <div class="modal-body">
            <p>Confirma a exclusão do item?</p>
        </div>

        <div class="modal-footer">
            <button type="button" class="btn btn-danger" id="btn-confirm-delete" data-loading-text="Excluindo...">Excluir</button>
            <button type="button" class="btn btn-primary" data-dismiss="modal">Cancelar</button>
        </div>
    </div>

    <form action="#" class="hide" id="form-delete" method="post">
        <input type="hidden" name="_method" value="delete" />
    </form>

    <div id="modal-message" class="modal hide fade">
        <div class="modal-header">
            <a href="#" class="close">&times;</a>
            <h3 id="modal-message-title">Mensagem</h3>
        </div>

        <div class="modal-body">
            <p id="modal-message-text"></p>
        </div>

        <div class="modal-footer">
            <a href="#" class="btn btn-primary" data-dismiss="modal">OK</a>
        </div>
    </div><!-- #modal-message -->


    <!-- ========================================================================
         JS
         ======================================================================== -->
    @section('scripts')
        <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/vendor/plugins.min.js') }}"></script>
        <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/components/ckeditor/ckeditor.js') }}"></script>
        <script type="text/javascript" src="{{ asset('packages/escapework/manager/assets/js/main.js') }}"></script>
    @show
</body>
</html>
