<?php namespace EscapeWork\Manager\Repositories\PageAction;

use Mockery as m;
use stdClass;

class EloquentPageActionRepositoryTest extends \PHPUnit_Framework_TestCase
{

    public function setUp()
    {
        $this->model      = m::mock('EscapeWork\Manager\Models\PageAction');
        $this->repository = new EloquentPageActionRepository($this->model);
    }

    public function test_get_default_actions()
    {
        $this->model->shouldReceive('getDefaultActions')->once()->withNoArgs()->andReturn([]);

        $this->assertTrue(is_array($this->repository->getDefaultActions()));
    }

    public function test_insert_new()
    {
        $data = array('page_id' => 1, 'title' => 'Insert', 'type' => 'read');
        $this->model->shouldReceive('newFromBuilder')->once()->andReturn($this->model);
        $this->model->shouldReceive('fill')->once()->with($data)->andReturn($this->model);
        $this->model->shouldReceive('save')->once()->andReturn(true);

        $this->assertTrue($this->repository->insertNew($data['page_id'], $data['title'], $data['type']));
    }

    public function test_delete_by_page()
    {
        $this->model->shouldReceive('where')->once()->with('page_id', '=', 1)->andReturn($this->model);
        $this->model->shouldReceive('delete')->once()->andReturn(true);

        $this->assertTrue($this->repository->deleteByPage(1));
    }

    public function test_get_by_page()
    {
        $this->model->shouldReceive('where')->once()->with('page_id', '=', 1)->andReturn($this->model);
        $this->model->shouldReceive('get')->once()->andReturn([]);

        $this->assertTrue(is_array($this->repository->getByPage(1)));
    }

    public function test_has_changed_with_same_data_should_return_false()
    {
        $action1 = new stdClass;
        $action1->type = 'read';

        $action2 = new stdClass;
        $action2->type = 'create';

        $collection = [$action1, $action2];

        $types = ['read', 'create'];

        $this->assertFalse($this->repository->hasChanged($collection, $types));
    }

    public function test_has_changed_with_same_count_but_different_data_should_return_true()
    {
        $action1 = new stdClass;
        $action1->type = 'read';

        $action2 = new stdClass;
        $action2->type = 'create';

        $collection = [$action1, $action2];

        $types = ['read', 'update'];

        $this->assertTrue($this->repository->hasChanged($collection, $types));
    }

    public function test_has_changed_with_different_count_should_return_true()
    {
        $action1 = new stdClass;
        $action1->type = 'read';

        $action2 = new stdClass;
        $action2->type = 'create';

        $collection = [$action1, $action2];

        $types = ['read', 'create', 'update', 'delete'];

        $this->assertTrue($this->repository->hasChanged($collection, $types));
    }
}
